<?php

use UnicaenCode\Util;

/**
 * @var $this       \Application\View\Renderer\PhpRenderer
 * @var $controller \Laminas\Mvc\Controller\AbstractController
 * @var $container  \Psr\Container\ContainerInterface
 * @var $viewName   string
 * @var $viewFile   string
 */

$cg = \UnicaenCode\Util::codeGenerator();

$container->setService('request', new \Laminas\Http\Request());

$params = [
    'title' => 'Génération du PhpRenderer de l\'application',
];

$fullClassName = 'Application\View\Renderer\PhpRenderer';

if (!\Laminas\Console\Console::isConsole()){
?>
    <div class="alert alert-warning">
        <span class="glyphicon glyphicon glyphicon-thumbs-up"
              style="float: left;font-size:50pt;margin-right:.2em;margin-bottom:.2em"></span>
        Le PhpRenderer permet de bénéficier de l'auto-complétion des view helpers depuis vos vues.
        Pour l'utiliser, il convient de déclarer la ligne suivante au début de chaque vue :

        <?php phpDump('/* @var $this \\' . $fullClassName . ' */'); ?>

    </div>
<?php
}


$vhs = Util::introspection()->getViewHelpers();

$methods = [];
foreach ($vhs as $key => $class) {
    $rc = new \ReflectionClass($class);
    if ($rc->hasMethod('__invoke')) {
        $method    = $rc->getMethod('__invoke');
        $methods[] = ' * ' . Util::getMethodDocDeclaration($rc->getMethod('__invoke'), $key, '\\' . $class);
    } else {
        $methods[] = " * @method \\$class $key()";
    }
}

$params['template'] = 'ApplicationPhpRenderer';
$params['filename'] = Util::classFilename($fullClassName);
$params['methods']  = implode("\n", $methods);

$cg->generer($params);