<?php

namespace UnicaenCode;

use UnicaenCode\Generator\AwareInterface;
use UnicaenCode\Generator\AwareTrait;
use UnicaenCode\Generator\Factory;

$unicaenCodeDir = dirname(__DIR__);

return [
    'unicaen-code' => [
        'sqlformatter-file'    => $unicaenCodeDir . '/vendor/sql-formatter-master/lib/SqlFormatter.php',
        'geshi-file'           => $unicaenCodeDir . '/vendor/geshi/geshi.php',
        'view-dirs'            => [$unicaenCodeDir . '/code'],
        'template-dirs'        => [$unicaenCodeDir . '/code/template'],
        'params-dirs'          => [$unicaenCodeDir . '/code/params'],
        'generator-output-dir' => '/tmp/UnicaenCode',
        'generators-from'      => [
            'factory'        => [
                'generator' => Factory::class,
                'useParams' => ['class', 'type', 'author', 'subDir'],
            ],
            'awareTrait'     => [
                'generator' => AwareTrait::class,
                'useParams' => ['class', 'type','subDir', 'useGetter'],
            ],
            'awareInterface' => [
                'generator' => AwareInterface::class,
                'useParams' => ['class', 'type','subDir', 'useGetter'],
            ],
        ],
    ],

    'doctrine' => [
        'sql_logger_collector' => [
            'orm_default' => [
                'sql_logger' => DBAL\Logging\DebugStack::class,
            ],
        ],
    ],

    'controllers' => [
        'factories' => [
            'UnicaenCode\Controller' => Controller\Factory\ControllerFactory::class,
        ],
    ],

    'service_manager' => [
        'factories'  => [
            Service\ConfigService::class        => Service\Factory\ConfigServiceFactory::class,
            Service\CollectorService::class     => Service\Factory\CollectorServiceFactory::class,
            Service\IntrospectionService::class => Service\Factory\IntrospectionServiceFactory::class,
            Service\CodeGeneratorService::class => Service\Factory\CodeGeneratorServiceFactory::class,
        ],
        'invokables' => [
            DBAL\Logging\DebugStack::class => DBAL\Logging\DebugStack::class,
        ],
    ],

    'view_manager' => [
        'template_map' => [
            'unicaen-code/index' => $unicaenCodeDir . '/view/unicaen-code/index.phtml',
            'laminas-developer-tools/toolbar/unicaen-code'
                                 => $unicaenCodeDir . '/view/laminas-developer-tools/toolbar/unicaen-code.phtml',
            'laminas-developer-tools/toolbar/doctrine-orm-queries'
                                 => __DIR__ . '/../view/laminas-developer-tools/toolbar/doctrine-orm-queries.phtml',
        ],
    ],

    'router' => [
        'routes' => [
            'unicaen-code' => [
                'type'    => 'Segment',
                'options' => [
                    'route'    => '/unicaen-code[/:view]',
                    'defaults' => [
                        'controller' => 'UnicaenCode\Controller',
                        'action'     => 'index',
                    ],
                ],
            ],
        ],
    ],

    'console'            => [
        'router' => [
            'routes' => [
                'unicaen-code' => [
                    'options' => [
                        'type'     => 'catchall',
                        'route'    => 'UnicaenCode <script> [<p0>] [<p1>] [<p2>] [<p3>] [<p4>] [<p5>] [<p6>] [<p7>] [<p8>] [<p9>]',
                        'defaults' => [
                            'controller' => 'UnicaenCode\Controller',
                            'action'     => 'console',
                        ],
                    ],
                ],
            ],
        ],
    ],

    // intégration à la Laminas Developer Toolbar
    'laminas-developer-tools' => [
        'profiler' => [
            'collectors' => [
                Service\CollectorService::class => Service\CollectorService::class,
            ],
        ],
        'toolbar'  => [
            'entries' => [
                Service\CollectorService::class => 'laminas-developer-tools/toolbar/unicaen-code',
            ],
        ],
    ],

    // Intégration à BjyAuthorize
    'bjyauthorize'       => [
        'guards' => [
            'BjyAuthorize\Guard\Controller' => [
                ['controller' => 'UnicaenCode\Controller', 'roles' => []],
            ],
        ],
    ],
];